#!/usr/bin/env python
# -*- coding: utf-8 -*-

# extract building heights from EA open data and display that with the
# OSM ID. This is intended as a place holder to create a file useful for
# updating OSM with building heights.

# ************ IMPORTANT ******************
# Do not update OSM data using this method without first
# going through the Imports approval process.
# *****************************************

import psycopg2

def main():
	# open the database
	#Define our connection string & get a connection
	conn_string = "host='localhost' dbname='ey'"
	try:
		conn = psycopg2.connect(conn_string)
	except:
		print('Cannot open the database')
		sys.exit(10)
	
	# get the cursor
	cursor = conn.cursor()
	
	# Define the rectangle that encloses the buildings to find, using 
	# east, south, west and north. 
	# This could match the area of EA data loaded, so I define it in
	# OS coordinates. Use this in the WHERE clause to limit the buildings
	# retuned
	
	east = 503000
	west = 504000
	south = 432000
	north = 433000
	
	sql = "SELECT OSM_ID, ST_AsText(way) FROM planet_osm_polygon WHERE building IS NOT NULL AND ST_Transform(way,27700) && ST_MakeEnvelope(%s,%s,%s,%s,27700);"
	try:
		cursor.execute(sql, (east,south,west,north))
	except psycopg2.Error, e:
		print(e.pgerror)
	else:
		rows = cursor.fetchall()
		print(len(rows))
		
		# for every building found in the selected area try to find the 
		# height data for its foot print. There will probably be many
		# heights so only use max(height) to find the highest.
		for r in rows:
			sql = "SELECT max(height) FROM eadata where ST_Contains(ST_Transform(ST_GeomFromText('" + r[1] + "',900913),27700),locn);"
			try:
				cursor.execute(sql)
			except psycopg2.Error, e:
				print(e.pgerror)
			else:
				hr = cursor.fetchone()
				if hr[0] != None:
					print("OSM ID {0} height is {1}".format(r[0], hr[0]))
	# close db
	cursor.close()
	conn.close()
	
	return 0

if __name__ == '__main__':
	main()

